==> 0.0.6.tar.gz: example/lib/pages/conversion/component/msgBody.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/common/hexToColor.dart';

class MsgBody extends StatelessWidget {
  TextDirection textDirection = TextDirection.rtl;
  CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.end;
  TextAlign textAlign = TextAlign.left;
  EdgeInsetsGeometry padding = EdgeInsets.only(
    right: 12,
  );
  int type = 1;
  String name;
  String message;
  MsgBody({type = 1, name, message}) {
    if (type != 1) {
      this.textDirection = TextDirection.ltr;
      this.crossAxisAlignment = CrossAxisAlignment.start;
      this.padding = EdgeInsets.only(
        left: 12,
      );
    }
    this.type = type;
    this.message = message;
    this.name = name;
  }
  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Container(
        padding: padding,
        child: Column(
          crossAxisAlignment: crossAxisAlignment,
          children: [
            Row(
              textDirection: textDirection,
              children: [
                Text(
                  name,
                  textAlign: textAlign,
                  style: TextStyle(
                    fontSize: 12,
                    color: CommonColors.getTextWeakColor(),
                  ),
                ),
              ],
            ),
            Container(
              margin: EdgeInsets.only(top: 4),
              child: PhysicalModel(
                color: Colors.transparent,
                borderRadius: BorderRadius.circular(6),
                clipBehavior: Clip.antiAlias,
                child: Container(
                  padding: EdgeInsets.all(10),
                  decoration: BoxDecoration(
                    color: type == 1
                        ? hexToColor('006eff').withOpacity(0.1)
                        : hexToColor('f8f8f8').withOpacity(1),
                    border: Border.all(
                      width: 0.5,
                      style: BorderStyle.solid,
                      color: type == 1
                          ? hexToColor('006eff').withOpacity(0.3)
                          : hexToColor('e8e8e8').withOpacity(1),
                    ),
                    borderRadius: BorderRadius.circular(6),
                  ),
                  child: Text(
                    message,
                    textAlign: textAlign,
                    style: TextStyle(
                      fontSize: 16,
                      color: type == 1
                          ? hexToColor('171538')
                          : hexToColor('000000'),
                    ),
                  ),
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}

==> 0.0.10.tar.gz: example/lib/pages/conversion/component/msgBody.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/common/hexToColor.dart';

class MsgBody extends StatelessWidget {
  TextDirection textDirection = TextDirection.rtl;
  CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.end;
  TextAlign textAlign = TextAlign.left;
  EdgeInsetsGeometry padding = EdgeInsets.only(
    right: 12,
  );
  int type = 1;
  String name;
  String message;
  V2TimMessage msgobj;

  MsgBody({
    messageText,
    type,
    name,
    message,
  }) {
    if (type != 1) {
      this.textDirection = TextDirection.ltr;
      this.crossAxisAlignment = CrossAxisAlignment.start;
      this.padding = EdgeInsets.only(
        left: 12,
      );
    }

    this.type = type;
    this.message = messageText;
    this.name = name;
    this.msgobj = message;
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Container(
        padding: padding,
        child: Column(
          crossAxisAlignment: crossAxisAlignment,
          children: [
            Row(
              textDirection: textDirection,
              children: [
                Text(
                  name,
                  textAlign: textAlign,
                  style: TextStyle(
                    fontSize: 12,
                    color: CommonColors.getTextWeakColor(),
                  ),
                ),
              ],
            ),
            Container(
              margin: EdgeInsets.only(top: 4),
              child: PhysicalModel(
                color: Colors.transparent,
                borderRadius: BorderRadius.circular(6),
                clipBehavior: Clip.antiAlias,
                child: Container(
                  padding: EdgeInsets.all(10),
                  decoration: BoxDecoration(
                    color: type == 1
                        ? hexToColor('006eff').withOpacity(0.1)
                        : hexToColor('f8f8f8').withOpacity(1),
                    border: Border.all(
                      width: 0.5,
                      style: BorderStyle.solid,
                      color: type == 1
                          ? hexToColor('006eff').withOpacity(0.3)
                          : hexToColor('e8e8e8').withOpacity(1),
                    ),
                    borderRadius: BorderRadius.circular(6),
                  ),
                  child: msgobj.elemType == 3
                      ? Column(
                          children: msgobj.imageElem.imageList.map(
                            (e) {
                              if (e.type == 1) {
                                return Image.network(e.url);
                              } else {
                                return Container();
                              }
                            },
                          ).toList(),
                        )
                      : Text(
                          message,
                          textAlign: textAlign,
                          style: TextStyle(
                            fontSize: 16,
                            color: type == 1
                                ? hexToColor('171538')
                                : hexToColor('000000'),
                          ),
                        ),
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
